/* Stata code for examples from: 
Pickup, Mark. Introduction to Time Series Analysis. 
2015 SAGE Publications, Inc.
*/

*Chapter 1

**Table 1.3, thermostatic.dta
reg caprsocial caspsocial


*Chapter 2

**Figure 2.1 and 2.2, Germany.dta
tsset t
tsline vote, ytitle(Vote)
ac vote, ytitle(Autocorrelations of Vote)

**Google Example, Google trends data.dta
sum beatles if t>209 & t<314
sum beatles if t>314

sum gaga if t>209 & t<314
sum gaga if t>314

reg  beatles l.beatles if t>209 & t<314
reg  beatles l.beatles if t>314

reg gaga l.gaga if t>209 & t<314
reg gaga l.gaga if t>314

**Table 2.1, thermostatic.dta
reg caprsocial caspsocial cacounter


*Chapter 3

**Figure 3.3, thermostatic.dta
twoway (tsline caprsocial) in 16/32, ytitle(Public's Relative Preference) scheme(s1manual)

**Table 3.3, thermostatic.dta
reg caprsocial caspsocial cacounter cacounterx

**Figure 3.4, thermostatic.dta
twoway (tsline ukprsocial) in 4/24, ytitle(Public's Relative Preference) scheme(s1manual)

**Table 3.4, thermostatic.dta
reg ukprsocial ukspsocial ukcounter ukcounterx

**Table 3.5, thermostatic.dta
reg ukprsocial ukcounter ukcounterx in 7/24
predict ukprdetrend, res
label variable ukprdetrend "Detrended Preference"

**Table 3.6, thermostatic.dta
reg ukspsocial ukcounter ukcounterx in 7/24
predict ukspdetrend, res
label variable ukspdetrend "Detrended Spending"

**Figure 3.5, thermostatic.dta
twoway (tsline ukprdetrend) (tsline ukspdetrend, lpattern(dash)) in 7/24, xlabel(1976(4)1996) ytitle(Detrended Data) scheme(s1manual)

**Table 3.7, thermostatic.dta
regress ukprdetrend ukspdetrend, noconstant

**Figure 3.6, KSI.dta
tsline lnKSI

**Table 3.8, KSI.dta
regress lnKSI t m1-m11 SBlaw lnpetrol
test m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11

**Table 3.9, thermostatic.dta
reg caspsocial cacounter cacounterx in 17/32
predict caspdetrend, res
label variable caspdetrend "Detrended Spending"

reg caspdetrend l.caspdetrend in 17/32, noc 

reg caprsocial caspsocial cacounter cacounterx in 17/32
predict caresids in 17/32, residuals
wntestq caresids

**Table 3.10, thermostatic.dta
reg caprsocial caspsocial cacounter cacounterx in 17/32
estat bgodfrey, lag(1/6)

**Breusch-Pagan test statistics 
reg ukprsocial ukspsocial ukcounter ukcounterx
estat hettest ukspsocial ukcounter ukcounterx
predict ukresids2, residuals
sktest ukresids2

**Table 3.11, thermostatic.dta
reg usprsocial usspsocial uscounter uscounterx
predict usresids, residuals
wntestq usresids

**Table 3.12, thermostatic.dta
arima usprsocial usspsocial uscounter uscounterx, ar(1)
predict usresids2, residuals
wntestq usresids2

**Table 3.13, thermostatic.dta
newey usprsocial usspsocial uscounter uscounterx, lag(1)

***Table 3.14, legislative success Canada.dta
reg hocsuccess t c.t#c.t

***Table 3.15, legislative success Canada.dta
reg hocsuccess govparty govpop minority govpopxmin

display _b[govpop]+_b[govpopxmin]
test govpop+govpopxmin = 0
predict hocresids, residuals
wntestq hocresids
estat hettest govparty govpop minority govpopxmin
sktest hocresids

**Figure 3.10, legislative success Canada.dta
twoway (scatter hocresids t)


*Chapter 4

**Table 4.1, thermostatic.dt
regress usprsocial l.usprsocial usspsocial l.usspsocial uscounterx

**Q-test
predict residuals, residuals
wntestq residuals

**Wald test
testnl (_b[usspsocial] + _b[l.usspsocial])/(1-_b[l.usprsocial]) =0

**Table 4.2, Germany.dta
reg vote l.vote gdp unemp inf l.gdp l.unemp l.inf t

**Q-test
predict resids, residuals
wntestq resids

**Wald test
testnl (_b[inf] + _b[l.inf])/(1-_b[l.vote]) =0

*Table 4.3, thermostatic.dta
regress usprsocial l.usprsocial usspsocial uscounterx

**Portmanteau (Q) statistic 
predict residuals, res
wntestq residuals

**skewness and kurtosis test
sktest residuals

**Wald test
testnl _b[usspsocial]/(1-_b[l.usprsocial]) = 0

**Table 4.4, AR2 data
reg y l.y x 

**Portmanteau (Q) statistic 
predict resids, res
wntestq resids

reg y l.y ll.y x 

**Portmanteau (Q) statisti
predict resids2, res
wntestq resids2

**Table 4.5, Germany long.dta
reg govapprov SPDtrend CDUtrend cyc1 cyc2
predict govapdtdt, res

**Table 4.6, Germany long.dta
reg govapdtdt l.govapdtdt growth unemp inf l.growth l.unemp l.inf

**F tests
test growth + l.growth = 0
test inflation + l.inflation = 0
test unemployment + l.unemployment = 0

testnl (_b[inflation]+_b[l.inflation])/(1-_b[l.govapdtdt]) = 0
testnl (_b[unemployment]+_b[l.unemployment])/(1-_b[l.govapdtdt]) = 0

**Test for ARCH effects
estat archlm, lag(1)

*Table 4.7, Germany long.dta
arch govapdtdt l.govapdtdt growth unemp inf l.growth l.unemp l.inf, arch(1)

**Wald tests
test growth + l.growth = 0
test inflation + l.inflation = 0
test unemployment + l.unemployment = 0

testnl (_b[inflation]+_b[l.inflation])/(1-_b[l.govapdtdt]) = 0
testnl (_b[unemployment]+_b[l.unemployment])/(1-_b[l.govapdtdt]) = 0

**Table 4.8, EPA Bush.dta
arima Enforcements bdiffplus bdiffminus l.Whitman l.WhitmanQuit l.Holmstead l.Leavitt l.Johnson l.Sansonetti l.NSR l.CAIR, ma(2)

**Portmanteau (Q) statistic 
predict residuals, res
wntestq residuals

**Table 4.9, EPA Bush.dta
arima Enforcements bdiffplus bdiffminus l.Whitman l.WhitmanQuit l.Holmstead l.Leavitt l.Johnson l.Sansonetti l.NSR l.CAIR

**Portmanteau (Q) statistic 
predict residuals2, res
wntestq residuals2


*Chapter 5

**Figure 5.1, Simulated AR series
ac AR0_9, ytitle(Autocorrelation Function for Single Realisation)
ac ARneg0_9, ytitle(Autocorrelation Function for Single Realisation)

**Figure 5.2, Simulated AR series
pac AR0_9, ytitle(Partial Autocorrelation Function for Single Realisation)
pac ARneg0_9, ytitle(Partial Autocorrelation Function for Single Realisation)

**Figure 5.3, Simulated MA series
ac MApos, ytitle(Autocorrelation Function for Single Realisation)
ac MAneg, ytitle(Autocorrelation Function for Single Realisation)

**Figure 5.4, Simulated MA series
pac MApos, ytitle(Partial Autocorrelation Function for Single Realisation)
pac MAneg, ytitle(Partial Autocorrelation Function for Single Realisation)

**Figure 5.5, Canada93to00.dta
tsline libvote, xtitle(Year)

**Table 5.3, Canada93to00.dta
reg  libvote libtrend

**Figure 5.6, Canada93to00.dta
predict dtlibvote, res
tsline dtlibvote, xtitle(Year)

**Figure 5.7, Canada93to00.dta 
ac dtlibvote, lags(30) ytitle(ACF for Detrended Vote)
pac dtlibvote, lags(30) ytitle(PACF for Detrended Vote)

**Table 5.4, Canada93to00.dta
arima dtlibvote, ar(1,4)

**Portmanteau (Q) statistic, and ACF and PACF
predict residuals, res
wntestq residuals

**Figure 5.8, Canada93to00.dta 
ac residuals, lag(30) ytitle(ACF for Residuals)
pac residuals, lag(30) ytitle(PACF for Residuals)

**Table 5.5, Canada93to00.dat
arima dtlibvote, ar(1,4,7)

**Table 5.6, Canada93to00.dat
arima dtlibvote, ar(1,4) ma(7)

**Portmanteau (Q) statistic, and ACF and PACF
predict residuals2, res
wntestq residuals2

**Figure 5.9, Canada93to00.dta 
ac residuals2, lag(30) ytitle(ACF for Residuals)
pac residuals2, lag(30)ytitle(PACF for Residuals)

**Likelihood ratio test
arima dtlibvote, ar(1,4) ma(7)
estimates store unrestricted
arima dtlibvote, ar(1,4) 
estimates store restricted
lrtest unrestricted restricted

**Table 5.7, Canada93to00.dat
arima dtlibvote l3.gdp l3.inf l6.unemp, ar(1,4) ma(7)

**Table 5.8, Canada93to00.dat
arima dtlibvote l3.gdp l3.inf l6.unemp, ma(7)

**Portmanteau (Q) statistic, and ACF and PACF
predict residuals3, res
wntestq residuals3

**Figure 5.10, Canada93to00.dta 
ac residuals3, lag(30) ytitle(ACF for Residuals)
pac residuals3, lag(30) ytitle(PACF for Residuals)

**BIC comparison
arima dtlibvote l3.gdp l3.inf l6.unemp in 7/84, ma(7)
estat ic
arima dtlibvote in 7/84, ar(1,4) ma(7)
estat ic

**Figure 5.11, KSI.dta
arima lnKSI m1-m11 lnpetrol in 1/169
predict residuals, res
ac residuals, ytitle(ACF for Residuals)
pac residuals, ytitle(PACF for Residuals)

**Table 5.9, KSI.dta
arima lnKSI m1-m11 lnpetrol in 1/169, arima(1,0,1)

**Predicted values 
predict predlnKSI, dynamic(169) xb
label variable predlnKSI "Prediction of ln(KSI)"

**Figure 5.12
twoway (tsline lnKSI, lpattern(solid)) (tsline predlnKSI, lpattern(dash)), legend(order(1 "LnKSI"  2 "Prediction/Forecast of LnKSI" ))

**Table 5.10, KSI.dta
arima lnKSI m1-m11 lnpetrol SBlaw, arima(1,0,1)

**Portmanteau (Q) statistic
predict residuals2, res
wntestq residuals2

**Table 5.11, KSI.dta
arima lnKSI m1-m11 lnpetrol SBlaw_pulse, arima(1,0,1)

**Table 5.12, Can poll error and tone.dta
xcorr  d.Liberror B_Libtone, lag(5) table

**Table 5.13, Can poll error and tone.dta
reg B_Libtone d.Liberror ld.Liberror

**Figure 5.13, Germany long.dta
reg govapprov SPDtrend CDUtrend cyc1 cyc2
predict govapdtdc, res
reg govapdtdc l.govapdtdc growth unemp inf l.growth l.unemp l.inf
predict residuals, res
ac residuals, ytitle(ACF for Residuals)
pac residuals, ytitle(PACF for Residuals)

**Table 5.14a, Germany long.dta
arima govapdtdc l.govapdtdc growth unemp inf l.growth l.unemp l.inf, ma(1)
predict resids, res 
wntestq resids

**Figure 5.14, Germany long.dta
gen resids2 = resids*resids
ac resids2, ytitle(ACF for Squared Residuals)
pac resids2, ytitle(PACF for Squared Residuals)

**Table 5.14b, Germany long.dta
arch govapdtdc l.govapdtdc growth unemp inf l.growth l.unemp l.inf, ma(1) arch(1) garch(1)

**Portmanteau (Q) statistic, and ACF and PACF
predict residuals3, res
wntestq residuals3

**Figure 5.15, Germany long.dta
ac residuals3, ytitle(AC of Residuals)
pac residuals3, ytitle(PAC of Residuals)

**Figure 5.16, Germany long.dta
predict hresids, v
gen sresids = residuals3/sqrt(hresids)
ac sresids, ytitle(AC of Standardized Residuals)
pac sresids, ytitle(PAC of Standardized Residuals)
wntestq sresids

**LR test
arch govapdtdc l.govapdtdc growth unemp inf l.growth l.unemp l.inf, ma(1) arch(1) garch(1)
estimates store unrestricted
arch govapdtdc l.govapdtdc growth unemp inf l.growth l.unemp l.inf, ma(1) arch(1)  
estimates store restricted
lrtest unrestricted restricted


*Chapter 6

**Dickey-Fuller test, trust.dta
dfuller trust

**Augmented Dickey-Fuller tests, trust.dta
dfuller trust, drift
dfuller trust, trend
dfuller trust, trend lags(3) regress

**Phillips-Perron test, trust.dta
pperron trust, trend lags(4)

**Figure 6.4, trust.dta
ac d.trust, ytitle(ACF for Differenced Trust)
pac d.trust, ytitle(PACF for Differenced Trust)

**Table 6.2, trust.dta
arima d.trust d.engagement, ma(3)

**Figure 6.5, trust.dta
predict residuals, res 
ac residuals, lag(30) ytitle(ACF for Residuals)
pac residuals, lag(30) ytitle(PACF for Residuals)

**Portmanteau (Q) statistic, 
wntestq residuals

**Figure 6.6, Ostrom.dta
twoway (tsline us_defence_expenditures) (tsline ussr_defence_expenditures, lpattern(dash)), ytitle(US Dollars (millions)) ttitle(Year)

**Augmented Dickey-Fuller tests, Ostrom.dta
dfuller us_defence_expenditures, trend
dfuller us_defence_expenditures, drift
dfuller ussr_defence_expenditures, trend
dfuller ussr_defence_expenditures, drift

**Table 6.3, Ostrom.dta
reg us_defence_expenditures ussr_defence_expenditures year

**Dickey-Fuller test, Ostrom.dta
predict residuals, res
dfuller residuals

**Table 6.4, Ostrom.dta
reg d.us_defence_expenditures d.ussr_defence_expenditures l.residuals, noc

**Portmanteau (Q) statistic, 
predict residuals2, res
wntestq residuals2

**Table 6.5, Ostrom.dta
reg us_defence_expenditures ussr_defence_expenditures year d.ussr_defence_expenditures ld.ussr_defence_expenditures fd.ussr_defence_expenditures

**Table 6.6, Ostrom.dta
vecrank us_defence_expenditures ussr_defence_expenditures, trend(rtrend) max

**Table 6.7, Germany.dta
reg d.vote l.vote d.gdp l.gdp d.inf l.inf d.unemp l.unemp t

**F tests
testnl _b[l.gdp]/-_b[l.vote] = 0
testnl _b[l.inf]/-_b[l.vote] = 0
testnl _b[l.unemp]/-_b[l.vote] = 0

**Portmanteau (Q) statistic, 
predict residuals, res
wntestq residuals

**Breusch-Pagan test 
estat hettest l.vote d.gdp l.gdp d.inf l.inf d.unemp l.unemp t



